@@ -29,9 +29,11 @@ from cloudfoundry_client.v3.buildpacks import BuildpackManager
 from cloudfoundry_client.v3.domains import DomainManager
 from cloudfoundry_client.v3.feature_flags import FeatureFlagManager
 from cloudfoundry_client.v3.isolation_segments import IsolationSegmentManager
+from cloudfoundry_client.v3.organization_quotas import OrganizationQuotaManager
 from cloudfoundry_client.v3.processes import ProcessManager
 from cloudfoundry_client.v3.organizations import OrganizationManager
 from cloudfoundry_client.v3.service_brokers import ServiceBrokerManager
+from cloudfoundry_client.v3.service_credential_bindings import ServiceCredentialBindingManager
 from cloudfoundry_client.v3.service_instances import ServiceInstanceManager
 from cloudfoundry_client.v3.service_offerings import ServiceOfferingsManager
 from cloudfoundry_client.v3.service_plans import ServicePlanManager
@@ -101,8 +103,10 @@ class V3(object):
         self.isolation_segments = IsolationSegmentManager(target_endpoint, credential_manager)
         self.jobs = JobManager(target_endpoint, credential_manager)
         self.organizations = OrganizationManager(target_endpoint, credential_manager)
+        self.organization_quotas = OrganizationQuotaManager(target_endpoint, credential_manager)
         self.processes = ProcessManager(target_endpoint, credential_manager)
         self.service_brokers = ServiceBrokerManager(target_endpoint, credential_manager)
+        self.service_credential_bindings = ServiceCredentialBindingManager(target_endpoint, credential_manager)
         self.service_instances = ServiceInstanceManager(target_endpoint, credential_manager)
         self.service_offerings = ServiceOfferingsManager(target_endpoint, credential_manager)
         self.service_plans = ServicePlanManager(target_endpoint, credential_manager)
@@ -181,8 +185,7 @@ class CloudFoundryClient(CredentialManager):
 
             return self._rlpgateway
 
-    @staticmethod
-    def _get_info(target_endpoint: str, proxy: Optional[dict] = None, verify: bool = True) -> Info:
+    def _get_info(self, target_endpoint: str, proxy: Optional[dict] = None, verify: bool = True) -> Info:
         root_response = CloudFoundryClient._check_response(
             requests.get("%s/" % target_endpoint, proxies=proxy if proxy is not None else dict(http="", https=""), verify=verify)
         )
@@ -193,12 +196,16 @@ class CloudFoundryClient(CredentialManager):
         log_stream = root_links.get("log_stream")
         return Info(
             root_links["cloud_controller_v2"]["meta"]["version"],
-            root_links["login"]["href"],
+            self._resolve_login_endpoint(root_links),
             target_endpoint,
             logging.get("href") if logging is not None else None,
             log_stream.get("href") if log_stream is not None else None,
         )
 
+    @staticmethod
+    def _resolve_login_endpoint(root_links):
+        return (root_links.get("login") or root_links.get("uaa") or root_links.get("self"))["href"]
+
     @staticmethod
     def _is_token_expired(response: Response) -> bool:
         if response.status_code == HTTPStatus.UNAUTHORIZED.value:
